@@ -379,6 +379,8 @@ class OAuth1Service(Request):
         # set to True to use header authentication for this service
         self.header_auth = header_auth
 
+        self.auth_session = None
+
     def _construct_session(self, **kwargs):
         '''Construct the request session, supplying the consumer key and
         secret.
@@ -386,10 +388,30 @@ class OAuth1Service(Request):
         :param \*\*kwargs: Extra keyworded arguments to be passed to the
             OAuth1Hook constructor.
         '''
-        hook = OAuth1Hook(consumer_key=self.consumer_key,
-                          consumer_secret=self.consumer_secret,
-                          **kwargs)
-        return requests.session(hooks={'pre_request': hook})
+        self.hook = OAuth1Hook(consumer_key=self.consumer_key,
+                               consumer_secret=self.consumer_secret,
+                               **kwargs)
+        return requests.session(hooks={'pre_request': self.hook})
+
+    def _get_session(self, **kwargs):
+        '''Get the request session, update attributes on the hook instance.
+
+        :param \*\*kwargs: Updates for access_token, access_token_secret,
+            header_auth.'''
+        access_token = kwargs.get('access_token')
+        access_token_secret = kwargs.get('access_token_secret')
+        header_auth = kwargs.get('header_auth')
+
+        if self.auth_session is None:
+            self.auth_session = \
+                    self._construct_session(header_auth=self.header_auth)
+
+        if access_token is not None:
+            self.hook.access_token = access_token
+        if access_token_secret is not None:
+            self.hook.access_token_secret = access_token_secret
+        self.hook.header_auth = header_auth or self.header_auth
+        return self.auth_session
 
     def get_request_token(self, method='GET', **kwargs):
         '''Gets a request token from the request token endpoint.
@@ -397,15 +419,11 @@ class OAuth1Service(Request):
         :param method: A string representation of the HTTP method to be used.
         :param \*\*kwargs: Optional arguments. Same as Requests.
         '''
-        auth_session = \
-                self._construct_session(header_auth=self.header_auth)
-
+        auth_session = self._get_session()
         response = auth_session.request(method,
                                         self.request_token_url,
                                         **kwargs)
-
         response.raise_for_status()
-
         data = dict(parse_qsl(response.content))
         return data['oauth_token'], data['oauth_token_secret']
 
@@ -436,10 +454,10 @@ class OAuth1Service(Request):
         request_token = kwargs.pop('request_token')
         request_token_secret = kwargs.pop('request_token_secret')
 
-        auth_session = self._construct_session(
-                                access_token=request_token,
-                                access_token_secret=request_token_secret,
-                                header_auth=self.header_auth)
+        auth_session = \
+            self._get_session(access_token=request_token,
+                              access_token_secret=request_token_secret,
+                              header_auth=self.header_auth)
 
         response = auth_session.request(method,
                                         self.access_token_url,
@@ -447,20 +465,6 @@ class OAuth1Service(Request):
 
         return Response(response)
 
-    def get_authenticated_session(self, access_token, access_token_secret,
-            header_auth=False):
-        '''Returns an authenticated Requests session utilizing the hook.
-
-        :param access_token: The access token as returned by
-            :class:`get_access_token`
-        :param access_token_secret: The access token secret as returned by
-            :class:`get_access_token`
-        :param header_auth: Authenication via header, defaults to False.
-        '''
-        return self._construct_session(access_token=access_token,
-                                       access_token_secret=access_token_secret,
-                                       header_auth=header_auth)
-
     def request(self, method, url, **kwargs):
         '''Makes a request using :class:`_construct_session`.
 
@@ -471,18 +475,20 @@ class OAuth1Service(Request):
             :class:`get_access_token`.
         :param access_token_secret: The access token secret as returned by
             :class:`get_access_token`.
-        :param header_auth: Authenication via header, defaults to False.
+        :param header_auth: Authenication via header, defaults to None.
         :param allow_redirects: Allows a request to redirect, defaults to True.
         :param \*\*kwargs: Optional arguments. Same as Requests.
         '''
         access_token = kwargs.pop('access_token')
         access_token_secret = kwargs.pop('access_token_secret')
-        header_auth = kwargs.pop('header_auth', False)
+        header_auth = kwargs.pop('header_auth', None)
         allow_redirects = kwargs.pop('allow_redirects', True)
+
+        # grab session constructed on initialization
         auth_session = \
-            self._construct_session(access_token=access_token,
-                                    access_token_secret=access_token_secret,
-                                    header_auth=header_auth)
+            self._get_session(access_token=access_token,
+                              access_token_secret=access_token_secret,
+                              header_auth=header_auth)
 
         response = auth_session.request(method,
                                         url,
